from typing import Any

class OneWire:
    MATCH_ROM: int
    SKIP_ROM: int
    SEARCH_ROM: int
    def select_rom(self, *args, **kwargs) -> Any: ...
    def writebyte(self, *args, **kwargs) -> Any: ...
    def crc8(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readbyte(self, *args, **kwargs) -> Any: ...
    def readbit(self, *args, **kwargs) -> Any: ...
    def writebit(self, *args, **kwargs) -> Any: ...
    def reset(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class OneWireError(Exception): ...



"""
efficient arrays of numeric data. See: https://docs.micropython.org/en/v1.19.1/library/array.html

|see_cpython_module| :mod:`python:array` https://docs.python.org/3/library/array.html .

Supported format codes: ``b``, ``B``, ``h``, ``H``, ``i``, ``I``, ``l``,
``L``, ``q``, ``Q``, ``f``, ``d`` (the latter 2 depending on the
floating-point support).
"""
from typing import Optional, Any

class array:
    """
    Create array with elements of given type. Initial contents of the
    array are given by *iterable*. If it is not provided, an empty
    array is created.
    """

    def extend(self, iterable) -> Any:
        """
        Append new elements as contained in *iterable* to the end of
        array, growing it.
        """
        ...
    def decode(self, *args, **kwargs) -> Any: ...
    def append(self, val) -> Any:
        """
        Append new element *val* to the end of array, growing it.
        """
        ...
    def __init__(self, typecode, iterable: Optional[Any] = None) -> None: ...



from typing import Any

def check_bootsec(*args, **kwargs) -> Any: ...
def wifi(*args, **kwargs) -> Any: ...
def fs_corrupted(*args, **kwargs) -> Any: ...
def setup(*args, **kwargs) -> Any: ...

bdev: Any



from typing import Any

size: int
start_sec: int

class FlashBdev:
    SEC_SIZE: int
    def writeblocks(self, *args, **kwargs) -> Any: ...
    def ioctl(self, *args, **kwargs) -> Any: ...
    def readblocks(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

bdev: Any



from typing import Any

def apa102_write(*args, **kwargs) -> Any: ...

class APA102:
    ORDER: tuple
    def write(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class NeoPixel:
    ORDER: tuple
    def write(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...
